# LcT

This is the implementation of "LcT: Locally-enhanced Cross-window Vision Transformer". Our code is based on [Swin Transformer](https://github.com/microsoft/Swin-Transformer).

## Abstract

Since introducing vision transformers (ViTs), ViT-based models have outperformed convolutional neural networks (CNNs) on various vision tasks.
However, competitive ViTs are parameter-heavy and computationally expensive, restricting their applicability to tasks performed on resource-limited devices. 
In this paper, we propose a lightweight hybrid architecture leveraging the advantage of CNNs and ViTs, called LcT. It achieves the speed-accuracy trade-off with a small number of parameters and computational costs. The proposed LcT is based on two primary operations: 1) It divides the feature map into non-overlapping windows and utilizes the self-attention mechanism to capture cross-window information; 2) It captures local information within each window using a stack of local convolutional layers. The two procedures mentioned above cooperate to complete global information interaction. Our experimental results indicate that LcT is effective and efficient at classification and downstream vision tasks. 


## Requirements

- PyTorch==1.8.1
- torchvision==0.9.1
- timm==0.5.4



Other Requirements

```
pip install opencv-python==4.4.0.46 termcolor==1.1.0 yacs==0.1.8
pip install einops
```

## Main Results

##### Results on **ImageNet-1K**

| name      | acc@1 | #params | FLOPs | Throughputs(Images/s) |                                                              
| --------- | ----- | ------- | ----- | --------------------- | 
| LcT_Tiny  |  73.1 | 1.89M   | 0.63G | 1549                  | 
| LcT_Small |  76.7 | 3.22M   | 1.09G | 1250                  |
| LcT_Base  |  79.4 | 6.53M   | 2.65G | 672                   | 

The throughput is measured on a RTX80000 GPU with a batch size of 128.



## Usage

For classification on ImageNet-1K, to train, please run:

```
python -m torch.distributed.launch train.py --cfg <config-file> --data-path <imagenet-path> [--batch-size <batch-size-per-gpu> --output <output-directory>]
```

To evaluate accuracy and throughput, please run:

```
python -m torch.distributed.launch test.py --cfg <config-file> --data-path <imagenet-path> --checkpoint <checkpoint path> --gpu_id <gpu_id>  
```

## Object detection and semantic segmentation

- Object detection is based on [mmdetection](https://github.com/open-mmlab/mmdetection), which has been included in the document.
- Semantic segmentation is based on [mmsegmentation](https://github.com/open-mmlab/mmsegmentation), which has been included in the document.






## Acknowledgement

We are very grateful to [Swin-Transformer](https://github.com/microsoft/Swin-Transformer) for their open-source code.

