_base_ = [
    '../_base_/models/ssd320_lct.py', '../_base_/datasets/coco_detection.py',
    '../_base_/schedules/schedule_1x.py', '../_base_/default_runtime.py'
]

# dataset settings
image_size = (320, 320)
model = dict(
    backbone=dict(
        # init_cfg=dict(
        #     type='Pretrained', checkpoint=None),
        drop_path_rate=0.1,
        heads_dim=24,
        irb_ratio=3,
        window_size=[8, 4, 2, 1],
        kernel_size=[3, 3, 3, 3],
        depths=[2, 2, 4, 2],
        stem_channels=[16, 32, 48, 48],
        transformer_dims=[48, 96, 144, 192],
    ),
    neck=dict(
        type='LcTNeck',
        in_channels=(96, 144, 192),
        out_channels=(192, 256, 256, 192, 192, 192),
    ),
    bbox_head=dict(
        type='LcTHead',
        in_channels=(192, 256, 256, 192, 192, 192),
        anchor_generator=dict(
            type='SSDAnchorGenerator',
            scale_major=False,
            strides=[8, 16, 32, 64, 107, 320],
            ratios=[[2, 3], [2, 3], [2, 3], [2, 3], [2, 3], [2]],
            min_sizes=[22, 48, 105, 163, 220, 278],
            max_sizes=[48, 105, 163, 220, 278, 336]),
    ),
)

dataset_type = 'CocoDataset'
data_root = 'data/coco/'
img_norm_cfg = dict(mean=[123.675, 116.28, 103.53], std=[58.395, 57.12, 57.375], to_rgb=True)
train_pipeline = [
    dict(type='LoadImageFromFile', to_float32=True),
    dict(type='LoadAnnotations', with_bbox=True),
    dict(
        type='Expand',
        mean=img_norm_cfg['mean'],
        to_rgb=img_norm_cfg['to_rgb'],
        ratio_range=(1, 4)),
    dict(
        type='MinIoURandomCrop',
        min_ious=(0.1, 0.3, 0.5, 0.7, 0.9),
        min_crop_size=0.3),
    dict(type='Resize', img_scale=image_size, keep_ratio=False),
    dict(type='RandomFlip', flip_ratio=0.5),
    dict(
        type='PhotoMetricDistortion',
        brightness_delta=32,
        contrast_range=(0.5, 1.5),
        saturation_range=(0.5, 1.5),
        hue_delta=18),
    dict(type='Normalize', **img_norm_cfg),
    dict(type='Pad', size_divisor=320),
    dict(type='DefaultFormatBundle'),
    dict(type='Collect', keys=['img', 'gt_bboxes', 'gt_labels']),
]
test_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(
        type='MultiScaleFlipAug',
        img_scale=image_size,
        flip=False,
        transforms=[
            dict(type='Resize', keep_ratio=False),
            dict(type='Normalize', **img_norm_cfg),
            dict(type='ImageToTensor', keys=['img']),
            dict(type='Collect', keys=['img']),
        ])
]
data = dict(
    samples_per_gpu=32,
    workers_per_gpu=4,
    train=dict(pipeline=train_pipeline),
    val=dict(pipeline=test_pipeline),
    test=dict(pipeline=test_pipeline))

optimizer = dict(_delete_=True, type='AdamW', lr=0.0002, betas=(0.9, 0.999), weight_decay=0.03, )
# 5x
lr_config = dict(step=[35, 45, 52, 57], warmup_iters=600, gamma=0.3)
runner = dict(type='EpochBasedRunner', max_epochs=60)


