# model settings

input_size = 320
model = dict(
    type='SingleStageDetector',
    pretrained=None,
    backbone=dict(
        type='LcT',
        drop_path_rate=0.1,
        stem_type='conv',
        heads_dim=24,
        ffn_ratio=2,
        irb_ratio=4,
        window_size=[8, 4, 2, 1],
        kernel_size=[3, 3, 3, 3],
        depths=[2, 2, 6, 2],
        stem_channels=[16, 32, 64, 96],
        transformer_dims=[96, 144, 192, 240],
        frozen_stages=-1,
        out_indices=[1, 2, 3],
    ),
    neck=dict(
        type='LcTNeck',
        in_channels=(144, 192, 240),
        out_channels=(240, 320, 320, 240, 240, 240),
        level_strides=(2, 1, 1),
        level_paddings=(1, 0, 0),
        init_cfg=dict(type='TruncNormal', layer='Conv2d', std=0.03),
    ),
    bbox_head=dict(
        type='LcTHead',
        in_channels=(240, 320, 320, 240, 240, 240),
        num_classes=80,
        init_cfg=dict(type='Normal', layer='Conv2d', std=0.001),

        anchor_generator=dict(
            type='SSDAnchorGenerator',
            scale_major=False,
            strides=[8, 16, 32, 64, 107, 320],
            ratios=[[2, 3], [2, 3], [2, 3], [2, 3], [2], [2]],
            min_sizes=[22, 48, 105, 163, 220, 278],
            max_sizes=[48, 105, 163, 220, 278, 336]),

        bbox_coder=dict(
            type='DeltaXYWHBBoxCoder',
            target_means=[.0, .0, .0, .0],
            target_stds=[0.1, 0.1, 0.2, 0.2])
    ),
    train_cfg=dict(
        assigner=dict(
            type='MaxIoUAssigner',
            pos_iou_thr=0.5,
            neg_iou_thr=0.5,
            min_pos_iou=0.,
            ignore_iof_thr=-1,
            gt_max_assign_all=False),
        smoothl1_beta=1.,
        allowed_border=-1,
        pos_weight=-1,
        neg_pos_ratio=3,
        debug=False),
    test_cfg=dict(
        nms_pre=1000,
        nms=dict(type='nms', iou_threshold=0.45),
        min_bbox_size=0,
        score_thr=0.02,
        max_per_img=200))
cudnn_benchmark = True
