# model settings
norm_cfg = dict(type='BN', requires_grad=True)
act_cfg = dict(type='Swish')
model = dict(
    type='EncoderDecoder',
    pretrained=None,
    backbone=dict(
        type='LcT',
        drop_path_rate=0.1,
        stem_type='conv',
        heads_dim=24,
        ffn_ratio=2,
        irb_ratio=4,
        window_size=[8, 4, 2, 2],
        kernel_size=[3, 3, 3, 3],
        depths=[2, 2, 6, 2],
        stem_channels=[16, 32, 64, 96],
        transformer_dims=[96, 144, 192, 240],
        frozen_stages=-1,
        strides=[2, 2, 1],
        out_indices=[2, 3],
        dilations=[1, 1, 1, 1],
    ),
    decode_head=dict(
        type='LcTASPPHead',
        in_channels=240,
        in_index=1,
        channels=240,
        bottleneck_ratio=0.5,
        aspp_ratio=2.5,
        neck_dropout=0.0,
        dilations=(1, 6, 12, 18),
        dropout_ratio=0.1,
        num_classes=21,
        norm_cfg=norm_cfg,
        act_cfg=act_cfg,
        align_corners=False,
        loss_decode=dict(
            type='CrossEntropyLoss', use_sigmoid=False, loss_weight=1.0)),

    auxiliary_head=dict(
        type='LcTFCNHead',
        in_channels=192,
        in_index=0,
        channels=192,
        fcn_ratio=3,
        num_convs=1,
        concat_input=False,
        dropout_ratio=0.1,
        num_classes=21,
        norm_cfg=norm_cfg,
        act_cfg=act_cfg,
        align_corners=False,
        loss_decode=dict(
            type='CrossEntropyLoss', use_sigmoid=False, loss_weight=0.4)),
    # model training and testing settings
    train_cfg=dict(),
    test_cfg=dict(mode='whole'))
